<?php

namespace Litecms\Contentdatum\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Contentdatum\Models\Contentdata;

class ContentdataPolicy
{

    /**
     * Determine if the given user can view the contentdata.
     *
     * @param UserPolicy $user
     * @param Contentdata $contentdata
     *
     * @return bool
     */
    public function view(UserPolicy $user, Contentdata $contentdata)
    {
        if ($user->canDo('contentdatum.contentdata.view') && $user->isAdmin()) {
            return true;
        }

        return $contentdata->user_id == user_id() && $contentdata->user_type == user_type();
    }

    /**
     * Determine if the given user can create a contentdata.
     *
     * @param UserPolicy $user
     * @param Contentdata $contentdata
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('contentdatum.contentdata.create');
    }

    /**
     * Determine if the given user can update the given contentdata.
     *
     * @param UserPolicy $user
     * @param Contentdata $contentdata
     *
     * @return bool
     */
    public function update(UserPolicy $user, Contentdata $contentdata)
    {
        if ($user->canDo('contentdatum.contentdata.edit') && $user->isAdmin()) {
            return true;
        }

        return $contentdata->user_id == user_id() && $contentdata->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given contentdata.
     *
     * @param UserPolicy $user
     * @param Contentdata $contentdata
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Contentdata $contentdata)
    {
        return $contentdata->user_id == user_id() && $contentdata->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given contentdata.
     *
     * @param UserPolicy $user
     * @param Contentdata $contentdata
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Contentdata $contentdata)
    {
        if ($user->canDo('contentdatum.contentdata.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contentdata.
     *
     * @param UserPolicy $user
     * @param Contentdata $contentdata
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Contentdata $contentdata)
    {
        if ($user->canDo('contentdatum.contentdata.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
